package org.eclipse.cdt.managedbuilder.ui.wizards;

/**********************************************************************
 * Copyright (c) 2002,2003 Rational Software Corporation and others.
 * All rights reserved.   This program and the accompanying materials
 * are made available under the terms of the Common Public License v0.5
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v05.html
 * 
 * Contributors: 
 * Rational Software - Initial API and implementation
***********************************************************************/


import org.eclipse.cdt.ui.CUIPlugin;
import org.eclipse.core.runtime.CoreException;
import org.eclipse.core.runtime.IProgressMonitor;
import org.eclipse.core.runtime.NullProgressMonitor;
import org.eclipse.swt.widgets.TabFolder;

/**
 * Wizard to create a new C project that uses the managed make system.
 */
public class ManagedCWizard extends ManagedProjectWizard {
	
	private static final String WZ_TITLE = "MngCWizard.title";
	private static final String WZ_DESC = "MngCWizard.description";
	private static final String SETTINGS_TITLE= "MngCWizardSettings.title"; //$NON-NLS-1$
	private static final String SETTINGS_DESC= "MngCWizardSettings.description"; //$NON-NLS-1$

	public ManagedCWizard() {
		this(CUIPlugin.getResourceString(WZ_TITLE), CUIPlugin.getResourceString(WZ_DESC));
	}

	public ManagedCWizard(String title, String desc) {
		super(title, desc);
	}
	
	public void addTabItems(TabFolder folder) {
		super.addTabItems(folder);
		fTabFolderPage.setTitle(CUIPlugin.getResourceString(SETTINGS_TITLE));
		fTabFolderPage.setDescription(CUIPlugin.getResourceString(SETTINGS_DESC));
	}

	protected void doRun(IProgressMonitor monitor) throws CoreException {
		// Let the super class create and populate the standard project
		super.doRun(monitor);
		// Add the managed build nature
		if (newProject != null) {
			if (monitor == null) {
				monitor = new NullProgressMonitor();
			}
			monitor.beginTask("Creating Generated C Make Project", 3);

			// Add the managed build nature to the project
			addManagedBuildNature(newProject, monitor);

			monitor.done();
		}
	}
}
